Lenta.ru
Description: Новости, статьи, фотографии, видео. Семь дней в неделю, 24 часа в сутки.

Мир

### Устали от понаехавших

Европейские правительства не знают, что делать с мигрантами
Дмитрий Клипин

### Шура и балаган

Как решение УЕФА по крымским клубам разрушило карьеру управленца

## 20:17 Нидерланды отказались выполнить просьбу родственников жертв катастрофы Боинга»

Власти Нидерландов отказали родственникам жертв разбившегося над Украиной «Боинга» в передаче расследования обстоятельств крушения Организации Объединенных Наций. По мнению 20 членов семей погибших, чьи интересы представляет адвокатская контора, голландские власти медлят с проведением расследования и не смогли найти виновных.
Читать полностью
19:51 Меркель назвала невозможным военное решение конфликта на Украине
19:52 «Башнефть» стала государственной компанией
19:45 ЕС отказал странам «Южного потока» в компенсации из-за закрытия проекта
19:06 ФАС указала нефтяникам на несоответствие цен на АЗС рыночной ситуации
19:40 В Литве предложили удалять с заседаний пьяных депутатов
19:02 Журнал Playboy сократил сотрудников
Россия — 8 декабря 2014

# Мертвый сезон

Сочи после Олимпиады
18:50 Сегодня

### Путин связал зарплаты руководства госкомпаний со снижением издержек

18:11 Сегодня

### Алтайские таможенники задержали центнер монгольских носков

18:01 Сегодня

### Здание Скотланд-Ярда продано девелоперам из Абу-Даби

Экономика — 15:53 Сегодня

### Рубль под наблюдением

Американские и европейские СМИ о девальвации российской валюты
17:58 Сегодня

### Суд взыскал с туроператора «Лабиринт» свыше пяти миллионов рублей

16:48 Сегодня

### Пользователи Twitter приравняли микроблог замглавы Роскомнадзора к СМИ

16:05 Сегодня

### РПЦ сочла арт-объект «Око Саурона» опасным для Москвы

Экономика — 08:17 Сегодня

### Разница — 2 процента

«Лента.ру» выясняла, улучшится ли здоровье россиян с увеличением средней стоимости медицинских услуг
15:48 Сегодня

### Цена платины в России обновила исторический максимум

15:46 Сегодня

### Создатель World of Tanks собрался вложиться в российскую ракету

15:09 Сегодня

### Энерготарифы на Украине поднимут до рыночного уровня

— 14:10 Сегодня

### Поле чудес

Кризисные акции на рынке недвижимости: между выгодой и обманом
15:05 Сегодня

### Lurkmore отказалось удалять мем с Сюткиным

14:53 Сегодня

### Новый автомат Калашникова оценили в тысячу долларов

14:17 Сегодня

### В Виннице задержали растоптавшего президентский портрет активиста

Мир — 09:41 Сегодня

### «США вернули религиозные войны»

Интервью с бывшим директором израильской спецслужбы НАТИВ Яковом Кедми
14:02 Сегодня

### Депутаты Госдумы Соловьев и Федоров отказались сдать мандаты

Россия — 09:03 Сегодня

### Следующая станция — Новая Москва

В столице открыто метро «Тропарево»
12:40 Сегодня

### Певица Саша Project отсудила у пластических хирургов 90 тысяч рублей

12:49 Сегодня

### По факту бунта в челябинском СИЗО возбуждено уголовное дело

Интернет и СМИ — 21:41 8 декабря 2014

### По национальному вопросу с ветерком

Смена восточных имен водителей такси на русские вызвала бурю споров в Рунете
12:21 Сегодня

### Уведомления о пропущенных вызовах у «Мегафона» станут платными

12:12 Сегодня

### Леонардо ДиКаприо увез из ночного клуба 20 женщин

Мир — 16:51 8 декабря 2014

### Документ дня: Либертарианец против вражды с Россией

Рон Пол раскритиковал антироссийскую резолюцию Палаты представителей США
Россия — 00:59 8 декабря 2014

### «Чудес не бывает»

Сванидзе, Альтшулер и другие правозащитники о встречах с Путиным
11:54 Сегодня

### Флойд Мэйуэзер стал свидетелем убийства и самоубийства по интернету

18:24 Сегодня

### Главный нарколог России призвал шоу-бизнес очиститься от наркотиков

17:49 Сегодня

### В Китае начали вырабатывать электричество из купюр

17:28 Сегодня

### Путин назвал рост цен на продукты временным

17:10 Сегодня

### Владимир Кличко обратился к подписчикам в Instagram на английском

16:43 Сегодня

### Тимченко открестился от участия «в нехороших делах»

Россия — 14:38 Сегодня

### Ташкентский гамбит

О чем Владимир Путин намерен договориться с Исламом Каримовым
16:18 Сегодня

### Полиция прервала концерт группы «Чайф» в подземном переходе Екатеринбурга

16:01 Сегодня

### Олланд рассказал об освобождении последнего французского заложника

16:01 Сегодня

### Нобелевскую медаль первооткрывателя ДНК приобрел Алишер Усманов

— 16:37 Сегодня

### Ряд волшебных изменений

10 исторических зданий центра столицы до и после реновации
15:59 Сегодня

### Бразильский футболист подаст документы на получение гражданства России после свадьбы

15:51 Сегодня

### Немецкий суд прекратил дело в отношении бывшего нациста

Мир — 08:28 Сегодня

### Катехизис атлантиста

НАТО изложила принципы, на основе которых строит отношения с Россией
15:05 Сегодня

### В Новосибирске завели дело о нападении на главреда «Тайга.инфо»

14:51 Сегодня

### Турецкий пограничник застрелил двух сослуживцев и покончил с собой

14:40 Сегодня

### Принц Уильям и Барак Обама обсудили проблемы отцовства

— 11:57 Сегодня

### Бархатная революция

Как устроен новый полный привод BMW
13:34 Сегодня

### Порошенко рассказал о соблюдении режима прекращения огня в Донбассе

13:21 Сегодня

### Футболист «Ростова» справил малую нужду на поле во время матча

13:21 Сегодня

### Число обманутых дольщиков в Подмосковье сократилось втрое

13:00 Сегодня

### Пять девочек в Китае погибли во время игры в баскетбол

Россия — 02:18 Сегодня

### За сценой не постоял

Владимир Путин неожиданно расширил повестку визита в Санкт-Петербург
11:56 Сегодня

### В Харькове взорвали памятник УПА

11:40 Сегодня

### Макаревич получит премию за защиту прав человека

Из жизни — 08:01 7 декабря 2014

### Семеро по лавкам

Самые известные семерняшки в мире отпраздновали 17-летие
11:01 Сегодня

### Завершено следствие по делу об аварии в московском метро

10:49 Сегодня

### Курс доллара превысил 54 рубля

10:26 Сегодня

### Хозяйка Сердитого котика опровергла слухи о рекордных заработках

10:22 Сегодня

### Депутат назвал сенатора троллем из-за реакции на статью «Ленты.ру»

Первая мировая — 14:36 8 декабря 2014

### Океанский зигзаг адмирала Шпее

Новое лицо морской войны

## Главное за сутки

17:58 В Европе нашли альтернативу «Южному потоку»
16:48 В Киеве представили стратегию возвращения Крыма
16:28 Путин удивился росту цен на бензин
15:18 Челябинский омбудсмен назвал вероятную причину беспорядков в СИЗО
11:45 Украинские военные объявили о прекращении огня
14:03 Олимпийский комитет Косово признан полноправным членом МОК
Спорт — 16:43 Сегодня

### Победа до весны

Для выхода в плей-офф Лиги чемпионов «Зениту» и ЦСКА нужно набрать по три очка
19:25 Сегодня

### Талибы убили проводившего вакцинацию от полиомиелита медработника

19:09 Сегодня

### Леброн Джеймс нарушил королевский протокол объятием с Кейт Миддлтон

17:38 Сегодня

### Монгол-диссидент вышел из китайской тюрьмы после 20 лет заключения

17:36 Сегодня

### Открыт прием заявок на участие в морских баталиях World of Warships

Бывший СССР — 09:40 Сегодня

### Полевой быт

Как живут ополченцы и силовики на востоке Украины
17:15 Сегодня

### Кейптаун возглавил рейтинг самых любимых туристами городов 2014 года

17:14 Сегодня

### На Украине запретили фильмы с Охлобыстиным

16:49 Сегодня

### Депутат Федоров назвал себя народным артистом Госдумы

16:03 Сегодня

### ЧМ-2014 по футболу и эпидемия Эболы оказались темами года на Facebook

Из жизни — 08:15 Сегодня

### «Пирамида Хеопса — типичный коровник»

Самые неожиданные отзывы о главных мировых достопримечательностях
15:08 Сегодня

### Британский министр обороны раскритиковала фигуру Ким Кардашьян

15:04 Сегодня

### СМИ сообщили о переходе главы Россотрудничества Косачева в Совфед

14:29 Сегодня

### Меркель стало плохо во время интервью

14:56 Сегодня

### Японские националисты обвинили Анджелину Джоли в расизме

14:44 Сегодня

### Анну Нетребко пригласят выступить в Донецке

14:25 Сегодня

### Яценюк оценил «Стену» на границе с Россией в полмиллиарда долларов

Россия — 09:00 Сегодня

### «Воздушные замки» Чечни

В Грозном остался район, который напоминает о тяжелом прошлом республики
14:01 Сегодня

### Россия прекратит выдачу 72-часовых виз для посещения Калининградской области

Россия — 11:31 Сегодня

### Пермские гаджеты

Шлем-спасатель и гидропоника на подоконнике как часть национальной технической инициативы
13:40 Сегодня

### Киргизского дипломата задержали на границе с секретными документами

13:26 Сегодня

### Израиль проведет боевые испытания «Пращи Давида»

13:17 Сегодня

### Натали Портман отказалась сниматься в фильме о Стиве Джобсе

Россия — 09:02 Сегодня

### Выборы оставили без «Голоса»

Иностранным агентам запрещено любое участие в российском избирательном процессе
13:10 Сегодня

### Сексуальную привлекательность женщин связали с высотой каблуков

11:45 Сегодня

### В Национальном антикоррупционном комитете подсчитали взяточников

Культура — 08:21 Сегодня

### Фонари-огнеметы и другие анонсы игровой выставки PlayStation Experience

Что предложат геймерам в 2015 году платформы Sony
11:23 Сегодня

### Amnesty International обвинила Израиль в военных преступлениях

10:55 Сегодня

### Телезвезда и ее супруг-рэпер найдены мертвыми в США

## Россия

Ташкентский гамбит
О чем Владимир Путин намерен договориться с Исламом Каримовым
Росприроднадзор обнаружил превышение диоксида серы в выбросах московского НПЗ
Власти Москвы утвердили ставки торгового сбора
Алтайские таможенники задержали центнер монгольских носков
Главный нарколог России призвал шоу-бизнес очиститься от наркотиков
Путин удивился росту цен на бензин
СМИ сообщили о досрочном сложении полномочий сенатора Николаевой
Все материалы

## Мир

Катехизис атлантиста
НАТО изложила принципы, на основе которых строит отношения с Россией
В Китае начали вырабатывать электричество из купюр
Талибы убили проводившего вакцинацию от полиомиелита медработника
«США вернули религиозные войны»
Интервью с бывшим директором израильской спецслужбы НАТИВ Яковом Кедми
Португальским каменщикам в Британии стали платить по тысяче фунтов в неделю
Задержанный за нападение на пассажиров поезда свалил вину на демона
Монгол-диссидент вышел из китайской тюрьмы после 20 лет заключения
Все материалы

## Бывший СССР

Полевой быт
Как живут ополченцы и силовики на востоке Украины
В Литве предложили удалять с заседаний пьяных депутатов
На Украине запретили фильмы с Охлобыстиным
В Киеве представили стратегию возвращения Крыма
Энерготарифы на Украине поднимут до рыночного уровня
Яценюк оценил «Стену» на границе с Россией в полмиллиарда долларов
Киргизского дипломата задержали на границе с секретными документами
Все материалы

## Экономика

Рубль под наблюдением
Американские и европейские СМИ о девальвации российской валюты
«Башнефть» стала государственной компанией
ЕС отказал странам «Южного потока» в компенсации из-за закрытия проекта
Путин связал зарплаты руководства госкомпаний со снижением издержек
ФАС указала нефтяникам на несоответствие цен на АЗС рыночной ситуации
В Европе нашли альтернативу «Южному потоку»
Путин назвал рост цен на продукты временным
Все материалы

## Силовые структуры

Звездные войны
Существует ли реальный конфликт между оперативными службами МВД и ФСБ России
Суд взыскал с туроператора «Лабиринт» свыше пяти миллионов рублей
Новый автомат Калашникова оценили в тысячу долларов
Челябинский омбудсмен назвал вероятную причину беспорядков в СИЗО
По факту бунта в челябинском СИЗО возбуждено уголовное дело
Главком ВМФ назвал Арктику и Крым приоритетными направлениями для флота
Новосибирский авиазавод передал Минобороны три бомбардировщика Су-34
Все материалы

## Наука и техника

Мобильный шпион
Как АНБ следит за пользователями с помощью мобильников
Эксперимент с лазером объяснил зарождение жизни от удара метеорита
Французские археологи нашли скелеты в оковах
Нобелевскую медаль первооткрывателя ДНК приобрел Алишер Усманов
Сексуальную привлекательность женщин связали с высотой каблуков
Создатель World of Tanks собрался вложиться в российскую ракету
Космический корабль Orion доставлен в порт Сан-Диего
Все материалы

## Оружие

Израиль проведет боевые испытания «Пращи Давида»
В США испугались возможностей китайского подводного флота
Boeing впервые запустил ракету с конвертоплана Osprey
Эстония заключит самую крупную военную сделку в своей истории
Индия купит 16 вертолетов Seahawk
Австралия подарила Папуа — Новой Гвинее десантный корабль
В США начались продажи универсального средства самообороны
Все материалы

## Спорт

Победа до весны
Для выхода в плей-офф Лиги чемпионов «Зениту» и ЦСКА нужно набрать по три очка
Платини отказался поддерживать Блаттера на выборах президента ФИФА
Леброн Джеймс нарушил королевский протокол объятием с Кейт Миддлтон
Министр спорта Сербии упрекнул МОК в политизированности
Владимир Кличко обратился к подписчикам в Instagram на английском
Бывшему тренеру «Амкара» предлагали почку вместо зарплаты
В Петербурге к ЧМ-2018 создадут намыв за 2,3 миллиарда рублей
Все материалы

## Культура

Фонари-огнеметы и другие анонсы игровой выставки PlayStation Experience
Что предложат геймерам в 2015 году платформы Sony
Открыт прием заявок на участие в морских баталиях World of Warships
«Многоходовочка» Васи Обломова попала в чарты российского iTunes
Полиция прервала концерт группы «Чайф» в подземном переходе Екатеринбурга
РПЦ сочла арт-объект «Око Саурона» опасным для Москвы
Японские националисты обвинили Анджелину Джоли в расизме
Московскому детскому саду подарили трехметровый арт-объект
Все материалы

## Интернет и СМИ

По национальному вопросу с ветерком
Смена восточных имен водителей такси на русские вызвала бурю споров в Рунете
«Ростелеком» запустил интерактивное ТВ в Москве
Журнал Playboy сократил сотрудников
Основанный россиянами стартап получил 20 миллионов долларов инвестиций
Пользователи Twitter приравняли микроблог замглавы Роскомнадзора к СМИ
«ВКонтакте» снизит лимит на число публикаций в сообществах в четыре раза
ЧМ-2014 по футболу и эпидемия Эболы оказались темами года на Facebook
Все материалы

## Из жизни

«Пирамида Хеопса — типичный коровник»
Самые неожиданные отзывы о главных мировых достопримечательностях
Семеро по лавкам
Самые известные семерняшки в мире отпраздновали 17-летие
Британская компания создала самый дорогой золотой велосипед
Кейптаун возглавил рейтинг самых любимых туристами городов 2014 года
Принц Уильям и Барак Обама обсудили проблемы отцовства
Британский министр обороны раскритиковала фигуру Ким Кардашьян
Телезвезда и ее супруг-рэпер найдены мертвыми в США
Все материалы

##

Пуховик цвета хаки
ГАЗ «Тигр» против Infiniti QX80
Появилось первое изображение хот-хэтча Hyundai
В России начали собирать новый Nissan X-Trail
Скелеты в сарае
Что можно найти на заброшенной французской ферме
Делай как я
Тест-драйв нового кроссовера BMW X6, который плюет на стереотипы
Концерн Chrysler добавит атмосферникам V6 турбонаддув
Компания Suzuki прекратила выпуск двух моделей
Все материалы

##

По ту сторону экрана
Существуют ли Хогвартс, отель «Гранд Будапешт» и квартира Шерлока Холмса в реальной жизни?
Отымущество
Все, что вы хотели знать о новом налоге на недвижимость, но боялись спросить
Построить за два часа
Загородный дом — это не так долго и дорого, как вы думаете
Столица определилась с минимальной кадастровой стоимостью
Пристегните ремни
Здания «с крыльями», которые нас удивили
Все материалы

## Первая мировая

Океанский зигзаг адмирала Шпее
Новое лицо морской войны
1914. Подвиг девицы Тычининой, переодетой в мужчину
«Евстафий» против «Гебена»
Десять минут, изменившие расстановку сил на Черном море в ноябре 1914 года
Сто лет после войны
Радикальная демократизация истории: от генералов к рядовым
Свидетели забытой войны
Первая мировая в документах и фотографиях артиллерийского поручика Андрея Шмидта
1914. Итальянские суда будут снабжены радиотелефонами
1914. Стрелы с бензином против германских дирижаблей
Все материалы

## Библиотека

Тутовая судьба
Мистическая история, рассказанная бабушкой писательницы Маши Трауб
Хенд-мейд со скидкой
Конкурс читательских рассказов «Ленты.ру»
Итоги страха и трепета
Победителем конкурса «Ленты.ру» на лучший хэллоуинский рассказ стала Олеся Головацкая
Случай в лесхозе
Конкурс читательских рассказов «Ленты.ру»
Совпадения
Рассказ — победитель конкурса хэллоуинских историй «Ленты.ру»
Бабка Фросина, ведьма и кошка Нюська
Конкурс читательских рассказов «Ленты.ру»
Все материалы